@@ -410,6 +410,21 @@ if_carrier(struct interface *ifp, const void *ifadata)
 	return LINK_DOWN;
 }
 
+bool
+if_roaming(struct interface *ifp)
+{
+
+/* Check for NetBSD as a safety measure.
+ * If other BSD's gain IN_IFF_TENTATIVE check they re-do DAD
+ * when the carrier comes up again. */
+#if defined(IN_IFF_TENTATIVE) && defined(__NetBSD__)
+	return ifp->flags & IFF_UP && ifp->carrier == LINK_DOWN;
+#else
+	UNUSED(ifp);
+	return false;
+#endif
+}
+
 static void
 if_linkaddr(struct sockaddr_dl *sdl, const struct interface *ifp)
 {
