@@ -167,10 +167,19 @@ static int if_addressexists(struct interface *, struct in_addr *);
 #define SYS_LAYER2	"/sys/class/net/%s/device/layer2"
 #define SYS_TUNTAP	"/sys/class/net/%s/tun_flags"
 
+#if defined(__aarch64__)
+static const char *mproc = "AArch64";
+int
+if_machinearch(char *str, size_t len)
+{
+
+	return snprintf(str, len, "%s", mproc);
+}
+#else
 static const char *mproc =
 #if defined(__alpha__)
 	"system type"
-#elif defined(__arm__) || defined(__aarch64__)
+#elif defined(__arm__)
 	"Hardware"
 #elif defined(__avr32__)
 	"cpu family"
@@ -232,6 +241,7 @@ if_machinearch(char *str, size_t len)
 	errno = ESRCH;
 	return -1;
 }
+#endif
 
 static int
 check_proc_int(struct dhcpcd_ctx *ctx, const char *path)
@@ -515,6 +525,21 @@ if_carrier(struct interface *ifp, __unused const void *ifadata)
 	return ifp->flags & IFF_RUNNING ? LINK_UP : LINK_DOWN;
 }
 
+bool
+if_roaming(struct interface *ifp)
+{
+
+#ifdef IFF_LOWER_UP
+	if (!ifp->wireless ||
+	    ifp->flags & IFF_RUNNING ||
+	    (ifp->flags & (IFF_UP | IFF_LOWER_UP)) != (IFF_UP | IFF_LOWER_UP))
+		return false;
+	return true;
+#else
+	return false;
+#endif
+}
+
 int
 if_getnetlink(struct dhcpcd_ctx *ctx, struct iovec *iov, int fd, int flags,
     int (*cb)(struct dhcpcd_ctx *, void *, struct nlmsghdr *), void *cbarg)
